@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2017-2020 Meltytech, LLC
+ * Copyright (c) 2017-2021 Meltytech, LLC
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -21,21 +21,21 @@ function trackHeight(isCurves) {
 
 function scrollIfNeeded(center) {
     var x = producer.position * timeScale;
-    if (!scrollView) return;
+    if (!tracksFlickable) return;
     if (settings.timelineCenterPlayhead || center) {
-        if (x > scrollView.flickableItem.contentX + scrollView.width * 0.5)
-            scrollView.flickableItem.contentX = x - scrollView.width * 0.5;
-        else if (x < scrollView.width * 0.5)
-            scrollView.flickableItem.contentX = 0;
-        else if (x < scrollView.flickableItem.contentX + scrollView.width * 0.5)
-            scrollView.flickableItem.contentX = x - scrollView.width * 0.5;
+        if (x > tracksFlickable.contentX + tracksFlickable.width * 0.5)
+            tracksFlickable.contentX = x - tracksFlickable.width * 0.5;
+        else if (x < tracksFlickable.width * 0.5)
+            tracksFlickable.contentX = 0;
+        else if (x < tracksFlickable.contentX + tracksFlickable.width * 0.5)
+            tracksFlickable.contentX = x - tracksFlickable.width * 0.5;
     } else {
-        if (x > scrollView.flickableItem.contentX + scrollView.width - 50)
-            scrollView.flickableItem.contentX = x - scrollView.width + 50;
+        if (x > tracksFlickable.contentX + tracksFlickable.width - 50)
+            tracksFlickable.contentX = x - tracksFlickable.width + 50;
         else if (x < 50)
-            scrollView.flickableItem.contentX = 0;
-        else if (x < scrollView.flickableItem.contentX + 50)
-            scrollView.flickableItem.contentX = x - 50;
+            tracksFlickable.contentX = 0;
+        else if (x < tracksFlickable.contentX + 50)
+            tracksFlickable.contentX = x - 50;
     }
 }
 
@@ -74,8 +74,8 @@ function clamp(x, minimum, maximum) {
 }
 
 function scrollMax() {
-    var maxWidth = Math.max(scrollView.flickableItem.contentWidth - scrollView.width + 14, 0)
-    var maxHeight = Math.max(scrollView.flickableItem.contentHeight - scrollView.height + 14, 0)
+    var maxWidth = Math.max(tracksFlickable.contentWidth - tracksFlickable.width + 14, 0)
+    var maxHeight = Math.max(tracksFlickable.contentHeight - tracksFlickable.height + 14, 0)
     return Qt.point(maxWidth, maxHeight)
 }
 
@@ -97,16 +97,16 @@ function onMouseWheel(wheel) {
             var y = wheel.pixelDelta.y
             // Track pads provide both horizontal and vertical.
             if (!y || Math.abs(x) > 2)
-                scrollView.flickableItem.contentX = clamp(scrollView.flickableItem.contentX - x, 0, scrollMax().x)
-            scrollView.flickableItem.contentY = clamp(scrollView.flickableItem.contentY - y, 0, scrollMax().y)
+                tracksFlickable.contentX = clamp(tracksFlickable.contentX - x, 0, scrollMax().x)
+            tracksFlickable.contentY = clamp(tracksFlickable.contentY - y, 0, scrollMax().y)
         } else {
             // Vertical only mouse wheel requires modifier for vertical scroll.
             if (wheel.modifiers === Qt.AltModifier) {
                 n = Math.round((application.OS === 'OS X'? wheel.angleDelta.y : wheel.angleDelta.x) / 2)
-                scrollView.flickableItem.contentY = clamp(scrollView.flickableItem.contentY - n, 0, scrollMax().y)
+                tracksFlickable.contentY = clamp(tracksFlickable.contentY - n, 0, scrollMax().y)
             } else {
                 n = Math.round(wheel.angleDelta.y / 2)
-                scrollView.flickableItem.contentX = clamp(scrollView.flickableItem.contentX - n, 0, scrollMax().x)
+                tracksFlickable.contentX = clamp(tracksFlickable.contentX - n, 0, scrollMax().x)
             }
         }
     }
